@@ -8,6 +8,9 @@ class BenchmarkDBResource(object):
     def __init__(self, db_name="performance_test"):
         self.sql = SqlConnection(db_name=db_name)
 
+    def __del__(self):
+        del self.sql
+
     def _get_search_match_string(self, test_key=None, project_name=None, begin_time=None, end_time=None, test_name=None):
         search_str = "SELECT * FROM _tests"
         is_first_filter = True
