@@ -21,13 +21,12 @@ class SqlConnection(object):
             SqlConnection.pool[self.db_name] =  PooledDB(creator=mysql, mincached=1 , maxcached=20 ,
                                                          host=self.host , port=self.port, user=self.user,
                                                          passwd=self.passwd, db=self.db_name,
-                                                         use_unicode=False,charset="utf8")
+                                                         use_unicode=T,charset="utf8")
         return SqlConnection.pool[self.db_name].connection()
-    #
-    # def __del__(self):
-    #     print("SqlConnection del")
-    #     self.cursor.close()
-    #     self.conn.close()
+
+    def __del__(self):
+        self.cursor.close()
+        self.conn.close()
 
     def execute_sql_command(self, command):
         results = list()
